﻿seasonManager = {};
addModEventListener(seasonManager);

function seasonManager:loadMap(name)

	g_currentMission.environment:addDayChangeListener(seasonManager);
	
	scriptVersion = "V0.6.1"
	
	print("--- weatherManager " .. scriptVersion .. " loaded ---");
	
	weatherManager.loadConfigFile();
	
	if periodicSeasons then
		print ("--- weatherManager: using standard cycle of " .. seasonDuration .. " day(s) per season ---");
		seasonManager.seasonCheck();
		seasonManager.nextSeasonCheck();
	else
		print ("--- weatherManager: using adapted cycle of " .. springDuration .. " day(s) per spring, " .. summerDuration .. " day(s) per summer, " .. autumnDuration .. " day(s) per autumn, " .. winterDuration .. " day(s) per winter ---");
		weatherManager.adaptedSeasons();
	end;
	if useLighting then
		weatherManager.generateLights();
	end;
	
	path = getUserProfileAppPath();
	local logFile = path.."/Lefthandright.xml";
	local CoreXML = LefthandrightCore.logXML;
	local ModID = getXMLInt(CoreXML, "LefthandrightCore.weatherManagerMod");
	
	if fileExists(logFile) then
		if ModID == 1 then
			print ("--- seasonManager: Mod registered ---");
			registration = 1;
		else
			print ("--- seasonManager: Mod unregistered. Install LefthandrightCore. https://www.modhoster.de/mods/seasonmanager ---")
			registration = 0;
		end;
	end;
	
end;

function seasonManager:deleteMap()
	
end;

function seasonManager:loadConfigFile()

	path = getUserProfileAppPath();
	
	savegameIndex = g_currentMission.missionInfo.savegameIndex;
	savegameFolderPath = g_currentMission.missionInfo.savegameDirectory;
	if savegameFolderPath == nil then
		savegameFolderPath = ('%ssavegame%d'):format(getUserProfileAppPath(), savegameIndex);
	end;
	
	configFile = savegameFolderPath .. "/seasonManager.xml";
	
	
	
	if fileExists(configFile) then
	
		print("--- seasonManager: loading " .. configFile .. " ---");
		configXML = loadXMLFile("seasonManager_XML", configFile, "seasonManager");
		version = getXMLString(configXML, "seasonManager.version");
		source = getXMLString(configXML, "seasonManager.source");
		periodicSeasons = getXMLBool(configXML, "seasonManager.periodicSeasons");
		seasonDuration = getXMLInt(configXML, "seasonManager.seasonDuration");
		springDuration = getXMLInt(configXML, "seasonManager.springDuration");
		XMLseason = getXMLString(configXML, "seasonManager.XMLseason");
		XMLposition = getXMLInt(configXML, "seasonManager.XMLposition");
		summerDuration = getXMLInt(configXML, "seasonManager.summerDuration");
		autumnDuration = getXMLInt(configXML, "seasonManager.autumnDuration");
		winterDuration = getXMLInt(configXML, "seasonManager.winterDuration");
		seasonShift = getXMLInt(configXML, "seasonManager.seasonShift");
		randomWeather = getXMLInt(configXML, "seasonManager.randomWeather");
		language = getXMLString(configXML, "seasonManager.language");
		useDisplay = getXMLBool(configXML, "seasonManager.useDisplay");
		displayX = getXMLFloat(configXML, "seasonManager.displayX");
		displayY = getXMLFloat(configXML, "seasonManager.displayY");
		displaySize = getXMLFloat(configXML, "seasonManager.displaySize");
		useLighting = getXMLBool(configXML, "seasonManager.useLighting");
		
		saveXMLFile(configXML);
	
	else
	
		seasonManager.createConfigFile();
		print("--- seasonManager: creating " .. configFile .. " ---");
		
	end;

	if version ~= scriptVersion then
		seasonManager.updateConfigFile();
	end;
	
	--if source == "Enter here the name of the mod portal where you downloaded the seasonManager. Gib hier den Namen des Modportals ein, wo du den seasonManager heruntergeladen hast" then
	--	sourceID = 1;
	--elseif source == "Modhoster" or source=="https://www.modhoster.de/" or source=="https://www.modhoster.com/" or source == "Forbidden Mods" or source == "http://forbidden-mods.phpbb8.de/" then
	--	sourceID = 2;
	--else
	--	sourceID = 0;
	--end;
	
	sourceID = 3;
	
end;

function seasonManager.createConfigFile()

	version = scriptVersion;
	source = "Enter here the name of the mod portal where you downloaded the seasonManager. Gib hier den Namen des Modportals ein, wo du den seasonManager heruntergeladen hast";
	periodicSeasons = true;
	seasonDuration = 1;
	XMLseason = "Summer";
	XMLposition = 1;
	springDuration = 1;
	summerDuration = 1;
	autumnDuration = 1;
	winterDuration = 1;
	seasonShift = 0;
	randomWeather = 10;
	language = "Enter here 'de' for german. Enter anything else for english. Gibt hier 'de' ein für deutsch. Gib hier irgendetwas anderes ein für englisch";
	useDisplay = true;
	displayX = 0.730;
	displayY = 0.982;
	displaySize = 0.02;
	useLighting = true;
	
end;

function seasonManager.updateConfigFile()
	print ("--- seasonManager: updating " .. configFile .. " ---");
	version = scriptVersion;
	setXMLString(configXML, "seasonManager.version", scriptVersion);
	saveXMLFile(configXML);
	seasonManager.createConfigFile();
end;

function seasonManager:adaptedSeasons()
	
	currentSeasonID = XMLseason;
	seasonPosition = XMLposition;
	
	if currentSeasonID == "Summer" then
		daysToNextSeason = summerDuration - seasonPosition;
	elseif currentSeasonID == "Autumn" then
		daysToNextSeason = autumnDuration - seasonPosition;
	elseif currentSeasonID == "Winter" then
		daysToNextSeason = winterDuration - seasonPosition;
	elseif currentSeasonID == "Spring" then
		daysToNextSeason = springDuration - seasonPosition;
	end;
	
	print ("--- seasonManager: " .. currentSeasonID .. " ---");
	
end;

function seasonManager:seasonCheck()
	
	local day = g_currentMission.environment.currentDay + seasonShift;
	
	currentSeason = (day / seasonDuration) % 4;
	
	if currentSeason > 0 and currentSeason <= 1 then
		currentSeasonID = "Summer";
	elseif currentSeason > 1 and currentSeason <= 2 then
		currentSeasonID = "Autumn";
	elseif currentSeason > 2 and currentSeason <= 3 then
		currentSeasonID = "Winter";
	elseif currentSeason == 0 or currentSeason <= 4 then
		currentSeasonID = "Spring";
	end;
	
	print ("--- seasonManager: " .. currentSeasonID .. " ---");
	
end;

function seasonManager:nextSeasonCheck()

	local day = g_currentMission.environment.currentDay + seasonShift;
	
	for counter = 0, seasonDuration do
	
		if ((day + counter) / seasonDuration) % 4 == 0 or ((day + counter) / seasonDuration) % 4 == 1 or ((day + counter) / seasonDuration) % 4 == 2 or ((day + counter) / seasonDuration) % 4 == 3 then
		
			daysToNextSeason = counter + 1;
			seasonPosition = seasonDuration - counter;
			print ("--- seasonManager: next season in " .. daysToNextSeason .. " day(s) ---");
			break
		
		else
			print ("--- seasonManager: searching next season ---");
		end;
	
	end;
	
end;

function seasonManager:save()
	
	seasonManager.createWeather();
	print ("--- seasonManager: saving config to " .. configFile .. " ---");
	
	configXML = createXMLFile("seasonManager_XML", configFile, "seasonManager");
	setXMLString(configXML, "seasonManager.version", version);
	setXMLString(configXML, "seasonManager.source", source);
	setXMLBool(configXML, "seasonManager.periodicSeasons", periodicSeasons);
	setXMLInt(configXML, "seasonManager.seasonDuration", seasonDuration);
	setXMLString(configXML, "seasonManager.XMLseason", XMLseason);
	setXMLInt(configXML, "seasonManager.XMLposition", XMLposition);
	setXMLInt(configXML, "seasonManager.springDuration", springDuration);
	setXMLInt(configXML, "seasonManager.summerDuration", summerDuration);
	setXMLInt(configXML, "seasonManager.autumnDuration", autumnDuration);
	setXMLInt(configXML, "seasonManager.winterDuration", winterDuration);
	setXMLInt(configXML, "seasonManager.seasonShift", seasonShift);
	setXMLInt(configXML, "seasonManager.randomWeather", randomWeather);
	setXMLString(configXML, "seasonManager.language", language);
	setXMLBool(configXML, "seasonManager.useDisplay", useDisplay);
	setXMLFloat(configXML, "seasonManager.displayX", displayX);
	setXMLFloat(configXML, "seasonManager.displayY", displayY);
	setXMLFloat(configXML, "seasonManager.displaySize", displaySize);
	setXMLBool(configXML, "seasonManager.useLighting", useLighting);
	
	saveXMLFile(configXML);
end;

function seasonManager:writeWeather()

	local key = "careerSavegame.environment.rains.rain(" .. weatherIndex .. ")";
	savegameFolderPath = getUserProfileAppPath().."savegame"..g_currentMission.missionInfo.savegameIndex;
	savegameXML = loadXMLFile("careerSavegame", savegameFolderPath .. "/careerSavegame.xml");
	
	setXMLBool(savegameXML, key .. "#isValid", true);
	setXMLString(savegameXML, key .. "#rainTypeId", eventType);
	setXMLFloat(savegameXML, key .. "#duration", 720);
	setXMLFloat(savegameXML, key .. "#startDayTime", 540);
	setXMLInt(savegameXML, key .. "#startDay", eventDay);
	
	weatherIndex = weatherIndex + 1;
	eventDay = eventDay + 1;
	
	saveXMLFile(savegameXML);

end;

function seasonManager:createWeather()

	if periodicSeasons then

		local day = g_currentMission.environment.currentDay + seasonShift;

		seasonManager.seasonCheck();
		seasonManager.nextSeasonCheck();
		
		print ("--- seasonManager: creating weather ---");
		
		if currentSeasonID == "Spring" then
			
			weatherIndex = 0;
			eventDay = day + 1;
			
			if daysToNextSeason > 1 then
				daysToNextSeasonAlternate = daysToNextSeason - 1;
				for counter = 1, daysToNextSeasonAlternate do
					if seasonDuration >= 3 and counter == 1 or counter == seasonDuration and math.random(100) <= randomWeather then
						eventType = "fog";
						seasonManager.writeWeather();
					else
						eventType = "cloudy";
						seasonManager.writeWeather();
					end;
				end;
			end;
			
			eventDay = day + daysToNextSeason + seasonDuration - 1;
			
			for counter = 1, seasonDuration do
				if seasonDuration >= 3 and counter == 1 or counter == seasonDuration and math.random(100) <= randomWeather then
						eventType = "fog";
						seasonManager.writeWeather();
					else
						eventType = "rain";
						seasonManager.writeWeather();
					end;
			end;
			
			for counter = 1, seasonDuration do
				if seasonDuration >= 3 and counter == 1 or counter == seasonDuration and math.random(100) <= randomWeather then
						eventType = "fog";
						seasonManager.writeWeather();
					else
						eventType = "hail";
						seasonManager.writeWeather();
					end;
			end;
			
			for counter = 1, seasonDuration do
				if seasonDuration >= 3 and counter == 1 or counter == seasonDuration and math.random(100) <= randomWeather then
						eventType = "fog";
						seasonManager.writeWeather();
					else
						eventType = "cloudy";
						seasonManager.writeWeather();
					end;
			end;
		
		elseif currentSeasonID == "Summer" then
			
			weatherIndex = 0;
			eventDay = day + daysToNextSeason - 1;
			for counter = 1, seasonDuration do
				if seasonDuration >= 3 and counter == 1 or counter == seasonDuration and math.random(100) <= randomWeather then
						eventType = "fog";
						seasonManager.writeWeather();
					else
						eventType = "rain";
						seasonManager.writeWeather();
					end;
			end;
			
			for counter = 1, seasonDuration do
				if seasonDuration >= 3 and counter == 1 or counter == seasonDuration and math.random(100) <= randomWeather then
						eventType = "fog";
						seasonManager.writeWeather();
					else
						eventType = "hail";
						seasonManager.writeWeather();
					end;
			end;
			
			for counter = 1, seasonDuration do
				if seasonDuration >= 3 and counter == 1 or counter == seasonDuration and math.random(100) <= randomWeather then
						eventType = "fog";
						seasonManager.writeWeather();
					else
						eventType = "cloudy";
						seasonManager.writeWeather();
					end;
			end;
			
		elseif currentSeasonID == "Autumn" then
			
			weatherIndex = 0;
			eventDay = day + 1;
			
			if daysToNextSeason > 1 then
				daysToNextSeasonAlternate = daysToNextSeason - 1;
				for counter = 1, daysToNextSeasonAlternate do
					if seasonDuration >= 3 and counter == 1 or counter == seasonDuration and math.random(100) <= randomWeather then
						eventType = "fog";
						seasonManager.writeWeather();
					else
						eventType = "rain";
						seasonManager.writeWeather();
					end;
				end;
			end
			
			eventDay = day + daysToNextSeason - 1;
			
			for counter = 1, seasonDuration do
				if seasonDuration >= 3 and counter == 1 or counter == seasonDuration and math.random(100) <= randomWeather then
						eventType = "fog";
						seasonManager.writeWeather();
					else
						eventType = "hail";
						seasonManager.writeWeather();
					end;
			end;
			
			for counter = 1, seasonDuration do
				if seasonDuration >= 3 and counter == 1 or counter == seasonDuration and math.random(100) <= randomWeather then
						eventType = "fog";
						seasonManager.writeWeather();
					else
						eventType = "cloudy";
						seasonManager.writeWeather();
					end;
			end;
			
			eventDay = eventDay + seasonDuration;
			
			for counter = 1, seasonDuration do
				if seasonDuration >= 3 and counter == 1 or counter == seasonDuration and math.random(100) <= randomWeather then
						eventType = "fog";
						seasonManager.writeWeather();
					else
						eventType = "rain";
						seasonManager.writeWeather();
					end;
			end;
		
		elseif currentSeasonID == "Winter" then
			
			weatherIndex = 0;
			eventDay = day + 1;
			
			if daysToNextSeason > 1 then
				daysToNextSeasonAlternate = daysToNextSeason - 1;
				for counter = 1, daysToNextSeasonAlternate do
					if seasonDuration >= 3 and counter == 1 or counter == seasonDuration and math.random(100) <= randomWeather then
						eventType = "fog";
						seasonManager.writeWeather();
					else
						eventType = "hail";
						seasonManager.writeWeather();
					end;
				end;
			end;
			
			eventDay = day + daysToNextSeason - 1;
			
			for counter = 1, seasonDuration do
				if seasonDuration >= 3 and counter == 1 or counter == seasonDuration and math.random(100) <= randomWeather then
						eventType = "fog";
						seasonManager.writeWeather();
					else
						eventType = "cloudy";
						seasonManager.writeWeather();
					end;
			end;
			
			eventDay = eventDay + seasonDuration;
			
			for counter = 1, seasonDuration do
				if seasonDuration >= 3 and counter == 1 or counter == seasonDuration and math.random(100) <= randomWeather then
						eventType = "fog";
						seasonManager.writeWeather();
					else
						eventType = "rain";
						seasonManager.writeWeather();
					end;
			end;
			
			for counter = 1, seasonDuration do
				if seasonDuration >= 3 and counter == 1 or counter == seasonDuration and math.random(100) <= randomWeather then
						eventType = "fog";
						seasonManager.writeWeather();
					else
						eventType = "hail";
						seasonManager.writeWeather();
					end;
			end;
			
		end;
	
	else
		
		seasonManager.adaptedSeasons();
		
		print ("--- seasonManager: creating weather ---");
		day = g_currentMission.environment.currentDay + seasonShift;
		
		if currentSeasonID == "Spring" then
			
			weatherIndex = 0;
			eventDay = day + 1;
			
			if daysToNextSeason > 1 then
				daysToNextSeasonAlternate = daysToNextSeason - 1;
				for counter = 1, daysToNextSeasonAlternate do
					eventType = "cloudy";
					seasonManager.writeWeather();
				end;
			end;
			
			eventDay = day + daysToNextSeason + summerDuration - 1;
			
			for counter = 1, autumnDuration do
				eventType = "rain";
				seasonManager.writeWeather();
			end;
			
			for counter = 1, winterDuration do
				eventType = "hail";
				seasonManager.writeWeather();
			end;
			
			for counter = 1, springDuration do
				eventType = "cloudy";
				seasonManager.writeWeather();
			end;
		
		elseif currentSeasonID == "Summer" then
			
			weatherIndex = 0;
			eventDay = day + daysToNextSeason - 1;
			for counter = 1, autumnDuration do
				eventType = "rain";
				seasonManager.writeWeather();
			end;
			
			for counter = 1, winterDuration do
				eventType = "hail";
				seasonManager.writeWeather();
			end;
			
			for counter = 1, springDuration do
				eventType = "cloudy";
				seasonManager.writeWeather();
			end;
			
		elseif currentSeasonID == "Autumn" then
			
			weatherIndex = 0;
			eventDay = day + 1;
			
			if daysToNextSeason > 1 then
				daysToNextSeasonAlternate = daysToNextSeason - 1;
				for counter = 1, daysToNextSeasonAlternate do
					eventType = "rain";
					seasonManager.writeWeather();
				end;
			end
			
			eventDay = day + daysToNextSeason - 1;
			
			for counter = 1, winterDuration do
				eventType = "hail";
				seasonManager.writeWeather();
			end;
			
			for counter = 1, springDuration do
				eventType = "cloudy";
				seasonManager.writeWeather();
			end;
			
			eventDay = eventDay + summerDuration;
			
			for counter = 1, autumnDuration do
				eventType = "rain";
				seasonManager.writeWeather();
			end;
		
		elseif currentSeasonID == "Winter" then
			
			weatherIndex = 0;
			eventDay = day + 1;
			
			if daysToNextSeason > 1 then
				daysToNextSeasonAlternate = daysToNextSeason - 1;
				for counter = 1, daysToNextSeasonAlternate do
					eventType = "hail";
					seasonManager.writeWeather();
				end;
			end;
			
			eventDay = day + daysToNextSeason - 1;
			
			for counter = 1, springDuration do
				eventType = "cloudy";
				seasonManager.writeWeather();
			end;
			
			eventDay = eventDay + summerDuration;
			
			for counter = 1, autumnDuration do
				eventType = "rain";
				seasonManager.writeWeather();
			end;
			
			for counter = 1, winterDuration do
				eventType = "hail";
				seasonManager.writeWeather();
			end;
			
		end;
		
	end;
	
end;

function seasonManager:generateLights()
	
	local cme = g_currentMission.environment;
	
	if currentSeasonID == "Summer" then
	
		cme.ambientCurve = AnimCurve:new(linearInterpolator3);
		cme.ambientCurve:addKeyframe({x=0.020, y=0.020, z=0.032, time = 0*60});
		cme.ambientCurve:addKeyframe({x=0.020, y=0.020, z=0.032, time = 3.75*60});
		cme.ambientCurve:addKeyframe({x=0.065, y=0.065, z=0.075, time = 4.01*60});
		cme.ambientCurve:addKeyframe({x=0.065, y=0.065, z=0.075, time = 4.02*60});
		cme.ambientCurve:addKeyframe({x=0.040, y=0.040, z=0.060, time = 4.25*60});
		cme.ambientCurve:addKeyframe({x=0.080, y=0.080, z=0.120, time = 5*60});
		cme.ambientCurve:addKeyframe({x=0.220, y=0.140, z=0.120, time = 6*60});
		cme.ambientCurve:addKeyframe({x=0.500, y=0.300, z=0.150, time = 9*60});
		cme.ambientCurve:addKeyframe({x=0.500, y=0.300, z=0.150, time = 17*60});
		cme.ambientCurve:addKeyframe({x=0.220, y=0.140, z=0.120, time = 18*60});
		cme.ambientCurve:addKeyframe({x=0.020, y=0.020, z=0.032, time = 21*60});
		cme.ambientCurve:addKeyframe({x=0.024, y=0.024, z=0.036, time = 21.85*60});
		cme.ambientCurve:addKeyframe({x=0.072, y=0.072, z=0.088, time = 22.01*60});
		cme.ambientCurve:addKeyframe({x=0.072, y=0.072, z=0.088, time = 22.02*60});
		cme.ambientCurve:addKeyframe({x=0.020, y=0.020, z=0.032, time = 22.15*60});
		cme.ambientCurve:addKeyframe({x=0.020, y=0.020, z=0.032, time = 24*60});
		
	elseif currentSeasonID == "Autumn" then
	
		cme.ambientCurve = AnimCurve:new(linearInterpolator3);
		cme.ambientCurve:addKeyframe({x=0.020, y=0.020, z=0.032, time = 0*60});
		cme.ambientCurve:addKeyframe({x=0.020, y=0.020, z=0.032, time = 3.75*60});
		cme.ambientCurve:addKeyframe({x=0.065, y=0.065, z=0.075, time = 4.01*60});
		cme.ambientCurve:addKeyframe({x=0.065, y=0.065, z=0.075, time = 4.02*60});
		cme.ambientCurve:addKeyframe({x=0.040, y=0.040, z=0.060, time = 4.25*60});
		cme.ambientCurve:addKeyframe({x=0.080, y=0.080, z=0.140, time = 5*60});
		cme.ambientCurve:addKeyframe({x=0.140, y=0.140, z=0.180, time = 6*60});
		cme.ambientCurve:addKeyframe({x=0.180, y=0.180, z=0.220, time = 9*60});
		cme.ambientCurve:addKeyframe({x=0.180, y=0.180, z=0.220, time = 17*60});
		cme.ambientCurve:addKeyframe({x=0.160, y=0.140, z=0.160, time = 18*60});
		cme.ambientCurve:addKeyframe({x=0.020, y=0.020, z=0.032, time = 21*60});
		cme.ambientCurve:addKeyframe({x=0.024, y=0.024, z=0.036, time = 21.85*60});
		cme.ambientCurve:addKeyframe({x=0.072, y=0.072, z=0.088, time = 22.01*60});
		cme.ambientCurve:addKeyframe({x=0.072, y=0.072, z=0.088, time = 22.02*60});
		cme.ambientCurve:addKeyframe({x=0.020, y=0.020, z=0.032, time = 22.15*60});
		cme.ambientCurve:addKeyframe({x=0.020, y=0.020, z=0.032, time = 24*60});
		
	elseif currentSeasonID == "Winter" then
	
		cme.ambientCurve = AnimCurve:new(linearInterpolator3);
		cme.ambientCurve:addKeyframe({x=0.020, y=0.020, z=0.032, time = 0*60});
		cme.ambientCurve:addKeyframe({x=0.020, y=0.020, z=0.032, time = 3.75*60});
		cme.ambientCurve:addKeyframe({x=0.065, y=0.065, z=0.075, time = 4.01*60});
		cme.ambientCurve:addKeyframe({x=0.065, y=0.065, z=0.075, time = 4.02*60});
		cme.ambientCurve:addKeyframe({x=0.040, y=0.040, z=0.060, time = 4.25*60});
		cme.ambientCurve:addKeyframe({x=0.040, y=0.060, z=0.140, time = 5*60});
		cme.ambientCurve:addKeyframe({x=0.060, y=0.080, z=0.160, time = 6*60});
		cme.ambientCurve:addKeyframe({x=0.080, y=0.100, z=0.200, time = 9*60});
		cme.ambientCurve:addKeyframe({x=0.080, y=0.100, z=0.200, time = 17*60});
		cme.ambientCurve:addKeyframe({x=0.100, y=0.080, z=0.180, time = 18*60});
		cme.ambientCurve:addKeyframe({x=0.020, y=0.020, z=0.032, time = 21*60});
		cme.ambientCurve:addKeyframe({x=0.024, y=0.024, z=0.036, time = 21.85*60});
		cme.ambientCurve:addKeyframe({x=0.072, y=0.072, z=0.088, time = 22.01*60});
		cme.ambientCurve:addKeyframe({x=0.072, y=0.072, z=0.088, time = 22.02*60});
		cme.ambientCurve:addKeyframe({x=0.020, y=0.020, z=0.032, time = 22.15*60});
		cme.ambientCurve:addKeyframe({x=0.020, y=0.020, z=0.032, time = 24*60});
		
	elseif currentSeasonID == "Spring" then
	
		cme.ambientCurve = AnimCurve:new(linearInterpolator3);
		cme.ambientCurve:addKeyframe({x=0.020, y=0.020, z=0.032, time = 0*60});
		cme.ambientCurve:addKeyframe({x=0.020, y=0.020, z=0.032, time = 3.75*60});
		cme.ambientCurve:addKeyframe({x=0.065, y=0.065, z=0.075, time = 4.01*60});
		cme.ambientCurve:addKeyframe({x=0.065, y=0.065, z=0.075, time = 4.02*60});
		cme.ambientCurve:addKeyframe({x=0.040, y=0.040, z=0.060, time = 4.25*60});
		cme.ambientCurve:addKeyframe({x=0.080, y=0.080, z=0.140, time = 5*60});
		cme.ambientCurve:addKeyframe({x=0.140, y=0.140, z=0.120, time = 6*60});
		cme.ambientCurve:addKeyframe({x=0.220, y=0.180, z=0.180, time = 9*60});
		cme.ambientCurve:addKeyframe({x=0.220, y=0.180, z=0.180, time = 17*60});
		cme.ambientCurve:addKeyframe({x=0.160, y=0.140, z=0.160, time = 18*60});
		cme.ambientCurve:addKeyframe({x=0.020, y=0.020, z=0.032, time = 21*60});
		cme.ambientCurve:addKeyframe({x=0.024, y=0.024, z=0.036, time = 21.85*60});
		cme.ambientCurve:addKeyframe({x=0.072, y=0.072, z=0.088, time = 22.01*60});
		cme.ambientCurve:addKeyframe({x=0.072, y=0.072, z=0.088, time = 22.02*60});
		cme.ambientCurve:addKeyframe({x=0.020, y=0.020, z=0.032, time = 22.15*60});
		cme.ambientCurve:addKeyframe({x=0.020, y=0.020, z=0.032, time = 24*60});
		
	end;
	
end;

function seasonManager:dayChanged()
	
	if periodicSeasons then
		seasonManager.seasonCheck();
		seasonManager.nextSeasonCheck();
	else
		if currentSeasonID == "Summer" then
			if seasonPosition == summerDuration then
				currentSeasonID = "Autumn"
				seasonPosition = 1;
			else
				seasonPosition = seasonPosition + 1;
			end;
		elseif currentSeasonID == "Autumn" then
			if seasonPosition == autumnDuration then
				currentSeasonID = "Winter"
				seasonPosition = 1;
			else
				seasonPosition = seasonPosition + 1;
			end;
		elseif currentSeasonID == "Winter" then
			if seasonPosition == winterDuration then
				currentSeasonID = "Spring"
				seasonPosition = 1;
			else
				seasonPosition = seasonPosition + 1;
			end;
		elseif currentSeasonID == "Spring" then
			if seasonPosition == springDuration then
				currentSeasonID = "Summer"
				seasonPosition = 1;
			else
				seasonPosition = seasonPosition + 1;
			end;
		end;
		
		XMLseason = currentSeasonID;
		XMLposition = seasonPosition;
		
		seasonManager.save();
		
		seasonManager.adaptedSeasons();
	end;
	if useLighting then
		seasonManager.generateLights();
	end;
	print ("--- seasonManager: day " .. tostring(g_currentMission.environment.currentDay) .. " ---");
	
end;

function seasonManager:mouseEvent(posX, posY, isDown, isUp, button)

end;

function seasonManager:keyEvent(unicode, sym, Modifier, isDown)

end;

function seasonManager:update()
	
end;

function seasonManager:draw()

	
	setTextColor(1, 1, 1, 1);
	
	if useDisplay and periodicSeasons then
		if language == "de" then
			if currentSeasonID == "Summer" then
				renderText(displayX, displayY, displaySize, seasonPosition .. "/" .. seasonDuration .. " Sommer");
			elseif currentSeasonID == "Autumn" then
				renderText(displayX, displayY, displaySize, seasonPosition .. "/" .. seasonDuration .. " Herbst");
			elseif currentSeasonID == "Winter" then
				renderText(displayX, displayY, displaySize, seasonPosition .. "/" .. seasonDuration .. " Winter");
			elseif currentSeasonID == "Spring" then
				renderText(displayX, displayY, displaySize, seasonPosition .. "/" .. seasonDuration .. " Frühling");
			end;
		else
			renderText(displayX, displayY, displaySize, seasonPosition .. "/" .. seasonDuration .. " " .. currentSeasonID);
		end;
	end;
	
	if useDisplay and not periodicSeasons then
		if language == "de" then
			if currentSeasonID == "Summer" then
				renderText(displayX, displayY, displaySize, seasonPosition .. "/" .. summerDuration .. " Sommer");
			elseif currentSeasonID == "Autumn" then
				renderText(displayX, displayY, displaySize, seasonPosition .. "/" .. autumnDuration .. " Herbst");
			elseif currentSeasonID == "Winter" then
				renderText(displayX, displayY, displaySize, seasonPosition .. "/" .. winterDuration .. " Winter");
			elseif currentSeasonID == "Spring" then
				renderText(displayX, displayY, displaySize, seasonPosition .. "/" .. springDuration .. " Frühling");
			end;
		else
			if currentSeasonID == "Summer" then
				renderText(displayX, displayY, displaySize, seasonPosition .. "/" .. summerDuration .. " Summer");
			elseif currentSeasonID == "Autumn" then
				renderText(displayX, displayY, displaySize, seasonPosition .. "/" .. autumnDuration .. " Autumn");
			elseif currentSeasonID == "Winter" then
				renderText(displayX, displayY, displaySize, seasonPosition .. "/" .. winterDuration .. " Winter");
			elseif currentSeasonID == "Spring" then
				renderText(displayX, displayY, displaySize, seasonPosition .. "/" .. springDuration .. " Spring");
			end;
		end;
	end;	
	
	if registration == 1 then
	
	elseif registration == 0 then
		renderText(0.002,0.022,0.018, "seasonManager wurde nicht registriert. Bitte lade und installiere LefthandrightCore. Weitere Informationen auf https://www.modhoster.de/mods/seasonmanager");
		renderText(0.002,0.002,0.018, "seasonManager has not been registered. Please download and install LefthandrightCore. Further information at https://www.modhoster.de/mods/seasonmanager");
	end;
	
	if sourceID == 1 then
		renderText(0.002,0.022,0.018, "Gibt den Namen des Modportals, wo du den seasonManager heruntergeladen hast, in die Datei " .. configFile .. " ein");
		renderText(0.002,0.002,0.018, "Enter the name of the mod portal where you downloaded the seasonManager in file " .. configFile);
	end;
	
	if sourceID == 0 then
		renderText(0.002,0.022,0.018, "Lade den seasonManager auf Modhoster.de herunter, um den Entwickler zu unterstützen");
		renderText(0.002,0.002,0.018, "Download the seasonManager on Modhoster.com to support the developer");
	end;
	
end;		


g_careerScreen.saveSavegame = Utils.appendedFunction(g_careerScreen.saveSavegame, seasonManager.save);